@@ -92,8 +92,8 @@ extern int checkforbadnick(struct channel *, char *, char *);
 extern int checkforautorejoin(struct channel *, char *, char *);
 extern int checkforpartrejoin(struct channel *, char *, char *);
 extern int checkforaction(struct channel *, char *, char *, int);
-extern int delnickbk(char *, char *);
-extern int delwordbk(char *, char *);
+extern int delnickbks(char *, char *, int);
+extern int delwordbks(char *, char *, int);
 extern int uptime(time_t *, time_t *);
 extern int deladmin(char *, int);
 extern int deladminmask(char *, char *);
@@ -111,7 +111,7 @@ extern int getrandommsg(struct channel *, char *, int, char *, int, int);
 extern int getjoincount(struct channel *, char *);
 extern int delserver(char *, int, int, int, int, int);
 extern int setpassword(struct channel *, char *, char *);
-extern int logoff(struct channel *, char *);
+extern int logoff(struct channel *, char *, int);
 extern int logon(struct channel *, struct botuser *, char *, char *, int);
 extern int timed_cmp(struct timed *, struct timed *);
 extern int isfriend(struct channel *, char *, char *);
@@ -122,6 +122,8 @@ extern int noexpiredlogons(struct channel *);
 extern int delchannelban(struct channel *, char *);
 extern int ischanopless(struct channel *);
 extern int joininprogress(void);
+extern int dbconnect(void);
+extern int dbping(void);
 extern unsigned int getrandom(unsigned int);
 extern struct authed *addnewauthed(struct channel *, time_t, char *, char *);
 extern struct botuser *addbotuser(char *, char *);
@@ -158,6 +160,10 @@ extern struct timed *timed_new(struct channel *, time_t, int, int, char *);
 extern struct mmode *mmode_new(struct channel *, time_t, char *, char *);
 extern struct channel *clonechannel(char *, char *);
 extern time_t lastoff(struct channel *, char *, char *);
+extern time_t getadmints(void);
+extern time_t getadminauhtedsts(void);
+extern time_t getuserts(struct channel *);
+extern time_t getuserauhtedsts(struct channel *);
 extern void sendadverts(struct channel *, char *, char *);
 extern void resetparts(struct channel *, char *, char *);
 extern void initpubmsgs(struct channel *);
@@ -187,6 +193,7 @@ extern void sendchannelnotice(struct channel *, int, char *);
 extern void addcommand(struct channel *, char *, int, char *, char *, char *);
 extern void delcommand(struct channel *, char *, int, char *, char *, char *);
 extern void editcommand(struct channel *, char *, int, char *, char *, char *);
+extern void extcommand(struct channel *, char *, int, char *, char *, char *);
 extern void listcommand(struct channel *, char *, int, char *, char *, char *);
 extern void logoffcommand(struct channel *, char *, int, char *, char *, char *);
 extern void logoncommand(struct channel *, char *, int, char *, char *, char *);
@@ -221,3 +228,5 @@ extern void timed_del(struct timed *);
 extern void mmode_del(struct channel *, struct mmode *);
 extern void validateflags(char *, char *, int);
 extern void resetfloodcounters(struct channel *, char *);
+extern void dbclose(void);
+extern void resetcommand(struct channel *, char *, int, char *, char *, char *);
