@@ -167,6 +167,10 @@ enum WHICHCOMMAND_RETURN_VALUES {
         OER_WHICHCOMMAND_CLEARBANS,
         OER_WHICHCOMMAND_CYCLE,
         OER_WHICHCOMMAND_BSTATS,
+        OER_WHICHCOMMAND_EXT,
+        OER_WHICHCOMMAND_DBCLOSE,
+        OER_WHICHCOMMAND_DBCONNECT,	
+        OER_WHICHCOMMAND_RESET,
 	OER_WHICHCOMMAND_INVALID
 };
 
@@ -315,6 +319,7 @@ enum OER_FLAGS_TYPE {
 #define OER_PERMBANS 25
 #define OER_LOGON_TIMEOUT 1800
 #define OER_REGISTERCONNECTION_TIMEOUT 600
+#define OER_MYSQL_CONNECTION_RETRY 60
 #define OER_BANVARS_AUTO_REJOIN 30
 #define OER_BANVARS_PART_REJOIN 600
 #define OER_BANVARS_PUBLIC_FLOOD 300
@@ -364,13 +369,14 @@ enum OER_FLAGS_TYPE {
 details possibly available on the oer+MySQL console"
 #define OER_REALNAME "http://oer.equnet.org/help.html"
 #define OER_UNKNOWN "unknown"
-#define OER_COPYRIGHT1 "oer+MySQL version 1.0-35, Copyright (C) 2000-2002 EQU <equ@equnet.org>"
+#define OER_COPYRIGHT1 "oer+MySQL version 1.0-36, Copyright (C) 2000-2002 EQU <equ@equnet.org>"
 #define OER_COPYRIGHT2 "oer+MySQL comes with ABSOLUTELY NO WARRANTY; for details see the\n\
 GNU General Public License (COPYING) provided with this distribution.\n\
 This is free software, and you are welcome to redistribute it under\n\
 certain conditions; again see COPYING for details.\n"
 
 struct mysqldb {
+	time_t isalive;
         char mysqldbdbhost[HOSTLEN + 1];
         char mysqldbdbname[TINYSTRINGLEN + 1];
         char mysqldbdbuser[TINYSTRINGLEN + 1];
