@@ -196,10 +196,13 @@ int main(int argc, char *argv[])
                 oer_debug(OER_DEBUG_FATAL, "main->loadconf() failed\n");
 		exit(EXIT_FAILURE);
         }
-	if(mysql_real_connect(&mystate->mysqldb.mysqldbconn, mystate->mysqldb.mysqldbdbhost, mystate->mysqldb.mysqldbdbuser, mystate->mysqldb.mysqldbdbpw, mystate->mysqldb.mysqldbdbname, 0, NULL, 0) == NULL) {
-		oer_debug(OER_DEBUG_FATAL, "main->mysql_real_connect() failed: %s\n", mysql_error(&mystate->mysqldb.mysqldbconn));
+	if(!dbconnect()) {
 		exit(EXIT_FAILURE);
         }
+	if(!dbping()) {
+		exit(EXIT_FAILURE);
+	}
+	mystate->mysqldb.isalive = time(NULL);
         if(do_console) {
 		oer_debug(OER_DEBUG_INFO, "console mode is on (debug messages will be shown on screen)\n");
 	}
