@@ -265,6 +265,8 @@ if [ "$CREATECONF" = "y" -o "$CREATECONF" = "Y" ]; then
     $ECHO ""
     $ECHO "oer+MySQL configuration follows"
     $ECHO ""
+    readln "Please specify bot ident (identifies this oer+MySQL in the database) [oer] " "oer"
+    HANDLE=$ans
     readln "Please specify default IRC nick [oer] " "oer"
     NICK=$ans
     readln "Please specify alternate IRC nick [oeroer] " "oeroer"
@@ -281,10 +283,10 @@ if [ "$CREATECONF" = "y" -o "$CREATECONF" = "Y" ]; then
     REALNAME=$ans
     readln "Please specify optional virtual host [] " ""
     VIRTHOST=$ans
-    readln "Please specify bot handle [oer] " "oer"
-    HANDLE=$ans
+    readln "Please specify optional proxy setup string [] " ""
+    PROXYSETUP=$ans
     
-    INSERT_CONF="INSERT INTO conf VALUES ('$NICK','$ALTNICK','$USERID','$USERMODES','$BOTFLAGS','$PREFIX','$REALNAME','$VIRTHOST',NULL,NULL,NULL,'$HANDLE')"
+    INSERT_CONF="INSERT INTO oer_conf VALUES ('$NICK','$ALTNICK','$USERID','$USERMODES','$BOTFLAGS','$PREFIX','$REALNAME','$VIRTHOST',NULL,NULL,NULL,'$PROXYSETUP','$HANDLE')"
 	
     readln "Please specify bot admin handle [EQU] " "EQU"
     ADMIN=$ans
@@ -311,14 +313,14 @@ if [ "$CREATECONF" = "y" -o "$CREATECONF" = "Y" ]; then
         $ECHO ""
     fi
     
-    INSERT_ADMINS="INSERT INTO admins VALUES ('$ADMIN','$ADMINFLAGS','$HANDLE')"
+    INSERT_ADMINS="INSERT INTO oer_admins VALUES ('$ADMIN','$ADMINFLAGS','$HANDLE')"
 
     readln "Please specify bot admin hostmask [equ@*.equnet.org] " "equ@*.equnet.org"
     ADMINHOSTMASK=$ans
-    INSERT_HOSTMASKS="INSERT INTO hostmasks VALUES ('$ADMINHOSTMASK','',1,'$ADMIN','$HANDLE')"
+    INSERT_HOSTMASKS="INSERT INTO oer_hostmasks VALUES ('$ADMINHOSTMASK','',1,'$ADMIN','$HANDLE')"
 
     if [ "$ISDYN" = "d" ]; then
-	INSERT_PASSWORDS="INSERT INTO passwords VALUES ('$ADMIN','',2,'$CRYPT','$HANDLE')"
+	INSERT_PASSWORDS="INSERT INTO oer_passwords VALUES ('$ADMIN','',2,'$CRYPT','$HANDLE')"
     fi
 
     readln "Please specify default IRC server to connect to [irc.equnet.org] " "irc.equnet.org"
@@ -336,7 +338,7 @@ if [ "$CREATECONF" = "y" -o "$CREATECONF" = "Y" ]; then
     readln "Please specify optional server password for $SERVER [] " ""
     SERVERPW=$ans
 
-    INSERT_SERVERS="INSERT INTO servers VALUES ('$SERVER','$PORT','$MODES','$PINGFREQ','$PROT','$NOISE','$SERVERPW','$HANDLE',NULL)"
+    INSERT_SERVERS="INSERT INTO oer_servers VALUES ('$SERVER','$PORT','$MODES','$PINGFREQ','$PROT','$NOISE','$SERVERPW','$HANDLE',NULL)"
 
     $ECHO ""
     $ECHO -n "Importing data into database... "
@@ -392,7 +394,7 @@ if [ "$CREATECONF" = "y" -o "$CREATECONF" = "Y" ]; then
     while [ $COUNTER -ne $KICKREASONS ]; do
 	REASON=`head -$COUNTER scripts/kickreasons.txt | tail -1`
 	REASON2=`echo $REASON | sed "s/'/''/"`
-        NREASON="INSERT INTO kickreasons VALUES ('$REASON2', '$HANDLE')"
+        NREASON="INSERT INTO oer_kickreasons VALUES ('$REASON2', '$HANDLE')"
 	if [ "$DBUSERPW" = "" ]; then
 	    LOGTHIS=`( $ECHO "$NREASON" | $1/mysql -h $HOST -u $DBUSER $DB ) 2>&1`
 	    RC=$?
