@@ -103,6 +103,20 @@ CREATE TABLE oer_conf (
   PRIMARY KEY (ident)
 ) TYPE=MyISAM PACK_KEYS=1;
 
+#
+# Table structure for table 'oer_ext'
+#
+
+CREATE TABLE oer_ext (
+  par1 VARCHAR(20) NOT NULL,
+  par2 VARCHAR(20),
+  par3 VARCHAR(20),
+  par4 VARCHAR(20),
+  par5 VARCHAR(20),
+  ident VARCHAR(20) NOT NULL,
+  vartext TEXT NOT NULL
+) TYPE=MyISAM PACK_KEYS=1;
+
 #
 # Table structure for table 'oer_floodvars'
 #
